@@ -6,7 +6,14 @@ from . import sfdics, str_byt
 sfhlib = '/afs/ipp/aug/ads/lib64/amd64_sles11/libsfh8.so.20201118'
 libsfh = ct.cdll.LoadLibrary(sfhlib)
 
-log = logging.getLogger()
+fmt = logging.Formatter('%(asctime)s | %(name)s | %(levelname)s: %(message)s', '%Y-%m-%d %H:%M:%S')
+hnd = logging.StreamHandler()
+hnd.setFormatter(fmt)
+hnd.setLevel(level=logging.INFO)
+logger = logging.getLogger('sfh')
+logger.addHandler(hnd)
+logger.setLevel(logging.INFO)
+logger.propagate = False
 
 
 class SFH:
@@ -109,7 +116,7 @@ class SFH:
         _len  = ct.byref(c_len)
 # Output
 
-        log.debug('Modpar test:', pn, typ, pnlen, len(dat))
+        logger.debug('Modpar test: %s %d %d %d', pn, typ, pnlen, len(dat))
         if fmt in sfdics.fmt2len.keys():
             name_len = sfdics.fmt2len[fmt]
             c_len  = ct.c_uint32(pnlen)
