@@ -212,7 +212,7 @@ class SFREAD:
                 return
             else:
                 self.shot = nshot
-                self.diag = diag
+                self.diag = diag.upper()
                 self.exp  = exp  # unused herein, but useful docu
 
         if os.path.isfile(self.sfile):
@@ -241,12 +241,12 @@ class SFREAD:
         if name not in self.cache.keys():
             if name in self.objects:
                 self.cache[name] = self.getobject(name)
-            if name in self.parsets:
+            elif name in self.parsets:
                 self.cache[name] = self.getparset(name)
-        if name in self.cache.keys():
-            return self.cache[name]
-        else:
-            return None
+            else:
+                logger.error('Signal %s not found in diag %s' %(name, self.diag))
+                return None
+        return self.cache[name]
 
 
     def getchunk(self, start, length):
@@ -304,6 +304,7 @@ class SFREAD:
         obj = str_byt.to_str(obj)
         data = None
         if obj not in self.sfh.keys():
+            logger.error('Signal %s not found in diag %s' %(obj, diag))
             return None
 # Don't uncomment the following lines, to allow 1 cal and 1 uncal reading
 #        if obj in self.cache.keys(): 
@@ -322,65 +323,63 @@ class SFREAD:
             x = np.array([sfo.size_x, sfo.size_y, sfo.size_z, sfo.n_steps])
             shape_arr = x[x != 0]
         else:
+            logger.error('Object %s is no signal, signalgroup, timebase nor areabase, skipping')
             return None
 
-        if otyp in (6, 7, 8, 13):
-            dfmt = sfo.data_format
-            if otyp == 8 and sfo.length == 0:
-                if sfo.tbase_type == 1: # PPG_prog, e.g. END:T-LM_END
-                    dout = self.ppg_time(obj)
-                else:   # ADC_intern, e.g. DCN:T-ADC-SL
-                    dout = (np.arange(sfo.n_steps, dtype=np.float32) - sfo.n_pre)/sfo.s_rate
-            else:
-                if dfmt in sfdics.fmt2len.keys(): # char variable
-                    dlen = sfdics.fmt2len[dfmt]
-                    bytlen = np.prod(shape_arr) * dlen
-                    data = np.chararray(shape_arr, itemsize=dlen, buffer=self.getchunk(sfo.address, bytlen), order='F')
-                else: # numerical variable
-                    sfmt = sfdics.fmt2struc[dfmt]
-                    type_len = np.dtype(sfmt).itemsize
-                    addr = sfo.address
-                    bytlen = np.prod(shape_arr) * type_len
-                    if otyp in (7, 8) or self.time_last(obj):
-                        if nbeg is None:
-                            nbeg = 0
-                        else:
-                            byt_beg = nbeg*np.prod(shape_arr[:-1])
-                            addr   += byt_beg*type_len
-                            bytlen -= byt_beg*type_len
-                            shape_arr[-1] -= nbeg
-                        if nend is not None:
-                            bytlen = (nend - nbeg)*np.prod(shape_arr[:-1])*type_len
-                            shape_arr[-1] = nend - nbeg
-                    data = np.ndarray(shape_arr, '>%s' %sfmt, self.getchunk(addr, bytlen), order='F')
+        dfmt = sfo.data_format
+        if otyp == 8 and sfo.length == 0:
+            if sfo.tbase_type == 1: # PPG_prog, e.g. END:T-LM_END
+                dout = self.ppg_time(obj)
+            else:   # ADC_intern, e.g. DCN:T-ADC-SL
+                dout = (np.arange(sfo.n_steps, dtype=np.float32) - sfo.n_pre)/sfo.s_rate
+        else:
+            if dfmt in sfdics.fmt2len.keys(): # char variable
+                dlen = sfdics.fmt2len[dfmt]
+                bytlen = np.prod(shape_arr) * dlen
+                data = np.chararray(shape_arr, itemsize=dlen, buffer=self.getchunk(sfo.address, bytlen), order='F')
+            else: # numerical variable
+                sfmt = sfdics.fmt2struc[dfmt]
+                type_len = np.dtype(sfmt).itemsize
+                addr = sfo.address
+                bytlen = np.prod(shape_arr) * type_len
+                if otyp in (7, 8) or self.time_last(obj):
+                    if nbeg is None:
+                        nbeg = 0
+                    else:
+                        byt_beg = nbeg*np.prod(shape_arr[:-1])
+                        addr   += byt_beg*type_len
+                        bytlen -= byt_beg*type_len
+                        shape_arr[-1] -= nbeg
+                    if nend is not None:
+                        bytlen = (nend - nbeg)*np.prod(shape_arr[:-1])*type_len
+                        shape_arr[-1] = nend - nbeg
+                data = np.ndarray(shape_arr, '>%s' %sfmt, self.getchunk(addr, bytlen), order='F')
 
 # LongLong in [ns] and no zero at TS06
-                if otyp == 8 and dfmt == 13: # RMC:TIME-AD0
-                    dout = 1e-9*(data - self.getts06())
-                else:
-                    dout = sfobj.SFOBJ(data, sfho=sfo) # Add metadata
+            if otyp == 8 and dfmt == 13: # RMC:TIME-AD0
+                dout = 1e-9*(data - self.getts06())
+            else:
+                dout = sfobj.SFOBJ(data, sfho=sfo) # Add metadata
 
 # Calibrated signals and signal groups
-                if otyp in (6, 7) and cal:
-                    pscal = self.lincalib(obj)
-                    if pscal is not None:
-                        for j in range(10):
-                            mult = 'MULTIA0%d' %j
-                            shif = 'SHIFTB0%d' %j
-                            if mult in pscal.keys():
+            if otyp in (6, 7) and cal:
+                pscal = self.lincalib(obj)
+                if pscal is not None:
+                    for j in range(10):
+                        mult = 'MULTIA0%d' %j
+                        shif = 'SHIFTB0%d' %j
+                        if mult in pscal.keys():
 # we need to fix the content of pscal for signagroups
 # assuming first entry wins
-                                if (pscal[mult].size > 1):
-                                    pscal[mult] = pscal[mult][0]
-                                    pscal[shif] = pscal[shif][0]
-                                dout = dout * pscal[mult] + pscal[shif]
-                            else:
-                                break
-                        if self.diag in ('DCN', 'DCK', 'DCR'):
-                            dout.phys_unit = '1/m^2'
+                            if (pscal[mult].size > 1):
+                                pscal[mult] = pscal[mult][0]
+                                pscal[shif] = pscal[shif][0]
+                            dout = dout * pscal[mult] + pscal[shif]
+                        else:
+                            break
+                    if self.diag in ('DCN', 'DCK', 'DCR'):
+                        dout.phys_unit = '1/m^2'
  
-        else:
-            dout = None
         return dout
 
 
@@ -429,7 +428,7 @@ class SFREAD:
                 if caltyp == 'LinCalib':
                     logger.info('PSet for calib: %s' %rel)
                     return self.getparset(rel)
-                elif caltyp == 'External':
+                elif caltyp == 'extCalib':
                     diag_ext = self.getparset(rel)['DIAGNAME']
                     diag_ext = ''.join([str_byt.to_str(x) for x in diag_ext])
                     shot_ext = libddc.previousshot(diag_ext)
